      Program torsion
C
C     Construct and diagonalize the Hamiltonian for a triply-degenerate
C     hindered rotor, following Flygare Section 4.2 (p. 128)
C
      Implicit NONE
      Integer MMax, LWork
      Parameter (MMax = 100, LWork = (2*MMax+1)**2)
C
C     Si2H6 well depth computed at MP2 optimized geometries using the
C     Schafer-Horn-Ahlrichs "tz2plarge" basis. I is the reduced moment
C     of intertia of one silane group rotating against the other, per
C     Flygare, using the calculated geometry.
C
      Double precision V, I
      Parameter (V = 393.850d0, I = 145.296d0)
C
      Double precision H(-MMax:MMax, -MMax:MMax), E(-MMax:MMax)
      Double precision Work(LWork)
C
      Integer M, J, Info
C
C     Hamiltonian matrix is mostly zero
C
      Do J = -MMax, MMax
         Do M = -MMax, MMax
            H(M, J) = 0.0d0
         EndDo
      EndDo
C
C     Fill non-zero elements: diagonal and M+/-3
C
      Do M = -MMax, MMax
         H(M, M) = M*M*I + (V/2.0d0)
         If ( M - 3 .ge. -MMax) H(M-3, M) = -V/4.0d0
         If ( M + 3 .le. +MMax) H(M+3, M) = -V/4.0d0
      EndDo
C
C     Diagonalize the Hamiltonian to get energies
C
      Call DSyEv('No eigenvectors', 'Lower triangle',
     $   2*MMax + 1, H, 2*MMax+1, E, Work, LWork, Info)
      If (Info .ne. 0) then
         Write (6, *) 'Trouble with diag ', Info
         Stop
      EndIf
C
C     Write out the energies.  We know that the order of the states
C     is really m=0, +1, -1, +2, -2, ... and that |m|=3n will be
C     split.
C
      J = -MMax
      Write (6, 9000) 0, E(J)
      J = J + 1
      Do M = 1, MMax
         Write (6, 9000) M, E(J), E(J+1)
         J = J + 2
      EndDo
 9000 Format(1X, I5, 2F20.10)
      Stop
      End

